@@ -34,6 +34,7 @@ __all__ = (
     "ResponseMetadataTypeDef",
     "AssociateNetworkSettingsRequestRequestTypeDef",
     "AssociateTrustStoreRequestRequestTypeDef",
+    "AssociateUserAccessLoggingSettingsRequestRequestTypeDef",
     "AssociateUserSettingsRequestRequestTypeDef",
     "BrowserSettingsSummaryTypeDef",
     "BrowserSettingsTypeDef",
@@ -46,10 +47,12 @@ __all__ = (
     "DeleteNetworkSettingsRequestRequestTypeDef",
     "DeletePortalRequestRequestTypeDef",
     "DeleteTrustStoreRequestRequestTypeDef",
+    "DeleteUserAccessLoggingSettingsRequestRequestTypeDef",
     "DeleteUserSettingsRequestRequestTypeDef",
     "DisassociateBrowserSettingsRequestRequestTypeDef",
     "DisassociateNetworkSettingsRequestRequestTypeDef",
     "DisassociateTrustStoreRequestRequestTypeDef",
+    "DisassociateUserAccessLoggingSettingsRequestRequestTypeDef",
     "DisassociateUserSettingsRequestRequestTypeDef",
     "GetBrowserSettingsRequestRequestTypeDef",
     "GetIdentityProviderRequestRequestTypeDef",
@@ -62,6 +65,8 @@ __all__ = (
     "GetTrustStoreCertificateRequestRequestTypeDef",
     "GetTrustStoreRequestRequestTypeDef",
     "TrustStoreTypeDef",
+    "GetUserAccessLoggingSettingsRequestRequestTypeDef",
+    "UserAccessLoggingSettingsTypeDef",
     "GetUserSettingsRequestRequestTypeDef",
     "UserSettingsTypeDef",
     "IdentityProviderSummaryTypeDef",
@@ -75,6 +80,8 @@ __all__ = (
     "ListTrustStoreCertificatesRequestRequestTypeDef",
     "ListTrustStoresRequestRequestTypeDef",
     "TrustStoreSummaryTypeDef",
+    "ListUserAccessLoggingSettingsRequestRequestTypeDef",
+    "UserAccessLoggingSettingsSummaryTypeDef",
     "ListUserSettingsRequestRequestTypeDef",
     "UserSettingsSummaryTypeDef",
     "UntagResourceRequestRequestTypeDef",
@@ -83,16 +90,19 @@ __all__ = (
     "UpdateNetworkSettingsRequestRequestTypeDef",
     "UpdatePortalRequestRequestTypeDef",
     "UpdateTrustStoreRequestRequestTypeDef",
+    "UpdateUserAccessLoggingSettingsRequestRequestTypeDef",
     "UpdateUserSettingsRequestRequestTypeDef",
     "AssociateBrowserSettingsResponseTypeDef",
     "AssociateNetworkSettingsResponseTypeDef",
     "AssociateTrustStoreResponseTypeDef",
+    "AssociateUserAccessLoggingSettingsResponseTypeDef",
     "AssociateUserSettingsResponseTypeDef",
     "CreateBrowserSettingsResponseTypeDef",
     "CreateIdentityProviderResponseTypeDef",
     "CreateNetworkSettingsResponseTypeDef",
     "CreatePortalResponseTypeDef",
     "CreateTrustStoreResponseTypeDef",
+    "CreateUserAccessLoggingSettingsResponseTypeDef",
     "CreateUserSettingsResponseTypeDef",
     "GetPortalServiceProviderMetadataResponseTypeDef",
     "UpdateTrustStoreResponseTypeDef",
@@ -105,6 +115,7 @@ __all__ = (
     "CreateNetworkSettingsRequestRequestTypeDef",
     "CreatePortalRequestRequestTypeDef",
     "CreateTrustStoreRequestRequestTypeDef",
+    "CreateUserAccessLoggingSettingsRequestRequestTypeDef",
     "CreateUserSettingsRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "TagResourceRequestRequestTypeDef",
@@ -115,12 +126,15 @@ __all__ = (
     "GetPortalResponseTypeDef",
     "UpdatePortalResponseTypeDef",
     "GetTrustStoreResponseTypeDef",
+    "GetUserAccessLoggingSettingsResponseTypeDef",
+    "UpdateUserAccessLoggingSettingsResponseTypeDef",
     "GetUserSettingsResponseTypeDef",
     "UpdateUserSettingsResponseTypeDef",
     "ListIdentityProvidersResponseTypeDef",
     "ListNetworkSettingsResponseTypeDef",
     "ListPortalsResponseTypeDef",
     "ListTrustStoresResponseTypeDef",
+    "ListUserAccessLoggingSettingsResponseTypeDef",
     "ListUserSettingsResponseTypeDef",
 )
 
@@ -159,6 +173,14 @@ AssociateTrustStoreRequestRequestTypeDef = TypedDict(
     },
 )
 
+AssociateUserAccessLoggingSettingsRequestRequestTypeDef = TypedDict(
+    "AssociateUserAccessLoggingSettingsRequestRequestTypeDef",
+    {
+        "portalArn": str,
+        "userAccessLoggingSettingsArn": str,
+    },
+)
+
 AssociateUserSettingsRequestRequestTypeDef = TypedDict(
     "AssociateUserSettingsRequestRequestTypeDef",
     {
@@ -288,6 +310,13 @@ DeleteTrustStoreRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeleteUserAccessLoggingSettingsRequestRequestTypeDef = TypedDict(
+    "DeleteUserAccessLoggingSettingsRequestRequestTypeDef",
+    {
+        "userAccessLoggingSettingsArn": str,
+    },
+)
+
 DeleteUserSettingsRequestRequestTypeDef = TypedDict(
     "DeleteUserSettingsRequestRequestTypeDef",
     {
@@ -316,6 +345,13 @@ DisassociateTrustStoreRequestRequestTypeDef = TypedDict(
     },
 )
 
+DisassociateUserAccessLoggingSettingsRequestRequestTypeDef = TypedDict(
+    "DisassociateUserAccessLoggingSettingsRequestRequestTypeDef",
+    {
+        "portalArn": str,
+    },
+)
+
 DisassociateUserSettingsRequestRequestTypeDef = TypedDict(
     "DisassociateUserSettingsRequestRequestTypeDef",
     {
@@ -408,6 +444,7 @@ PortalTypeDef = TypedDict(
         "rendererType": Literal["AppStream"],
         "statusReason": str,
         "trustStoreArn": str,
+        "userAccessLoggingSettingsArn": str,
         "userSettingsArn": str,
     },
     total=False,
@@ -444,6 +481,35 @@ TrustStoreTypeDef = TypedDict(
     total=False,
 )
 
+GetUserAccessLoggingSettingsRequestRequestTypeDef = TypedDict(
+    "GetUserAccessLoggingSettingsRequestRequestTypeDef",
+    {
+        "userAccessLoggingSettingsArn": str,
+    },
+)
+
+_RequiredUserAccessLoggingSettingsTypeDef = TypedDict(
+    "_RequiredUserAccessLoggingSettingsTypeDef",
+    {
+        "userAccessLoggingSettingsArn": str,
+    },
+)
+_OptionalUserAccessLoggingSettingsTypeDef = TypedDict(
+    "_OptionalUserAccessLoggingSettingsTypeDef",
+    {
+        "associatedPortalArns": List[str],
+        "kinesisStreamArn": str,
+    },
+    total=False,
+)
+
+
+class UserAccessLoggingSettingsTypeDef(
+    _RequiredUserAccessLoggingSettingsTypeDef, _OptionalUserAccessLoggingSettingsTypeDef
+):
+    pass
+
+
 GetUserSettingsRequestRequestTypeDef = TypedDict(
     "GetUserSettingsRequestRequestTypeDef",
     {
@@ -559,6 +625,7 @@ PortalSummaryTypeDef = TypedDict(
         "portalStatus": PortalStatusType,
         "rendererType": Literal["AppStream"],
         "trustStoreArn": str,
+        "userAccessLoggingSettingsArn": str,
         "userSettingsArn": str,
     },
     total=False,
@@ -611,6 +678,24 @@ TrustStoreSummaryTypeDef = TypedDict(
     total=False,
 )
 
+ListUserAccessLoggingSettingsRequestRequestTypeDef = TypedDict(
+    "ListUserAccessLoggingSettingsRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+UserAccessLoggingSettingsSummaryTypeDef = TypedDict(
+    "UserAccessLoggingSettingsSummaryTypeDef",
+    {
+        "kinesisStreamArn": str,
+        "userAccessLoggingSettingsArn": str,
+    },
+    total=False,
+)
+
 ListUserSettingsRequestRequestTypeDef = TypedDict(
     "ListUserSettingsRequestRequestTypeDef",
     {
@@ -760,6 +845,29 @@ class UpdateTrustStoreRequestRequestTypeDef(
     pass
 
 
+_RequiredUpdateUserAccessLoggingSettingsRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateUserAccessLoggingSettingsRequestRequestTypeDef",
+    {
+        "userAccessLoggingSettingsArn": str,
+    },
+)
+_OptionalUpdateUserAccessLoggingSettingsRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateUserAccessLoggingSettingsRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "kinesisStreamArn": str,
+    },
+    total=False,
+)
+
+
+class UpdateUserAccessLoggingSettingsRequestRequestTypeDef(
+    _RequiredUpdateUserAccessLoggingSettingsRequestRequestTypeDef,
+    _OptionalUpdateUserAccessLoggingSettingsRequestRequestTypeDef,
+):
+    pass
+
+
 _RequiredUpdateUserSettingsRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateUserSettingsRequestRequestTypeDef",
     {
@@ -816,6 +924,15 @@ AssociateTrustStoreResponseTypeDef = TypedDict(
     },
 )
 
+AssociateUserAccessLoggingSettingsResponseTypeDef = TypedDict(
+    "AssociateUserAccessLoggingSettingsResponseTypeDef",
+    {
+        "portalArn": str,
+        "userAccessLoggingSettingsArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 AssociateUserSettingsResponseTypeDef = TypedDict(
     "AssociateUserSettingsResponseTypeDef",
     {
@@ -866,6 +983,14 @@ CreateTrustStoreResponseTypeDef = TypedDict(
     },
 )
 
+CreateUserAccessLoggingSettingsResponseTypeDef = TypedDict(
+    "CreateUserAccessLoggingSettingsResponseTypeDef",
+    {
+        "userAccessLoggingSettingsArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 CreateUserSettingsResponseTypeDef = TypedDict(
     "CreateUserSettingsResponseTypeDef",
     {
@@ -1019,6 +1144,29 @@ class CreateTrustStoreRequestRequestTypeDef(
     pass
 
 
+_RequiredCreateUserAccessLoggingSettingsRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateUserAccessLoggingSettingsRequestRequestTypeDef",
+    {
+        "kinesisStreamArn": str,
+    },
+)
+_OptionalCreateUserAccessLoggingSettingsRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateUserAccessLoggingSettingsRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class CreateUserAccessLoggingSettingsRequestRequestTypeDef(
+    _RequiredCreateUserAccessLoggingSettingsRequestRequestTypeDef,
+    _OptionalCreateUserAccessLoggingSettingsRequestRequestTypeDef,
+):
+    pass
+
+
 _RequiredCreateUserSettingsRequestRequestTypeDef = TypedDict(
     "_RequiredCreateUserSettingsRequestRequestTypeDef",
     {
@@ -1134,6 +1282,22 @@ GetTrustStoreResponseTypeDef = TypedDict(
     },
 )
 
+GetUserAccessLoggingSettingsResponseTypeDef = TypedDict(
+    "GetUserAccessLoggingSettingsResponseTypeDef",
+    {
+        "userAccessLoggingSettings": UserAccessLoggingSettingsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateUserAccessLoggingSettingsResponseTypeDef = TypedDict(
+    "UpdateUserAccessLoggingSettingsResponseTypeDef",
+    {
+        "userAccessLoggingSettings": UserAccessLoggingSettingsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 GetUserSettingsResponseTypeDef = TypedDict(
     "GetUserSettingsResponseTypeDef",
     {
@@ -1186,6 +1350,15 @@ ListTrustStoresResponseTypeDef = TypedDict(
     },
 )
 
+ListUserAccessLoggingSettingsResponseTypeDef = TypedDict(
+    "ListUserAccessLoggingSettingsResponseTypeDef",
+    {
+        "nextToken": str,
+        "userAccessLoggingSettings": List[UserAccessLoggingSettingsSummaryTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 ListUserSettingsResponseTypeDef = TypedDict(
     "ListUserSettingsResponseTypeDef",
     {
